FactoryGirl.define do

  factory :wine do
    name { Forgery::Name.full_name }
    status { :published }

    factory :empty_wine do
      after(:create) do |wine, evaluator|
        wine.vintages = create_list(:vintage,
                                    1,
                                    wine: wine)
      end
    end

    factory :complete_wine do
      add_name "Grand cru"
      appelation  "Irouleguy"
      vinification "Lorem ipsum"
      culture_types  ["Bio"]
      production_area "Irouleguy"
      country {{"value"=> "France"}}
      grounds ['Calcaire']
      harvests ["Mécanique"]
      climates ["Océanique"]
      allergens ['Oeuf']
      ageing [{"key"=> "Barriques", "value"=> "6 mois"},
              {"key"=>"", "value"=>""}]

      transient { vintages_count 1 }
      after(:create) do |wine, evaluator|
        wine.color = create(:color).id
        wine.save
        wine.vintages = create_list(:complete_vintage,
                                    evaluator.vintages_count,
                                    wine: wine)
      end

      after(:stub) do |wine, evaluator|
        flavor = build_stubbed(:flavor)
        entry = build_stubbed(:food_entry)
        dish = build_stubbed(:food_dish)
        dessert = build_stubbed(:food_dessert)
        cheese = build_stubbed(:food_cheese)
        wine.vintages.build attributes_for(:complete_vintage,
                                           tasting_flavors: [flavor.id],
                                           tasting_food_entries: [entry.id],
                                           tasting_food_dishes: [dish.id],
                                           tasting_food_desserts: [dessert.id],
                                           tasting_food_cheeses: [cheese.id],
                                           wine: wine)
      end
    end
  end
end
