require 'rails_helper'

describe Wine do

  it { should be_timestamped_document.with(:created) }
  it { should be_timestamped_document.with(:updated) }

  it { should have_field(:name).of_type(String) }
  it { should have_field(:status).of_type(Symbol)
    .with_default_value_of(:draft)}
  it { should have_field(:interpro_id).of_type(Moped::BSON::ObjectId) }
  it { should have_field(:color).of_type(Moped::BSON::ObjectId) }
  it { should have_field(:sparkling_type).of_type(String) }

  it { should have_field(:add_name).of_type(String) }
  it { should have_field(:appelation).of_type(String) }
  it { should have_field(:vinification).of_type(String) }
  it { should have_field(:culture_types).of_type(Array)
    .with_default_value_of([]) }
  it { should have_field(:production_area).of_type(String) }
  it { should have_field(:country).of_type(Hash) }
  it { should have_field(:grounds).of_type(Array)
    .with_default_value_of([]) }
  it { should have_field(:harvests).of_type(Array)
    .with_default_value_of([]) }
  it { should have_field(:climates).of_type(Array)
    .with_default_value_of([]) }
  it { should have_field(:allergens).of_type(Array)
    .with_default_value_of([]) }
  it { should have_field(:ageing).of_type(Array)
    .with_default_value_of([]) }
  it { should have_field(:unofficial).of_type(Mongoid::Boolean)
    .with_default_value_of(false) }

  it { should validate_presence_of(:name) }
  it { should validate_presence_of(:interpro_id) }

  it { should belong_to(:producer) }
  it { should embed_many(:vintages) }
  it { should belong_to(:estate) }

  it { should have_many(:user_comments) }
end
